## Example plots for statistical difference

#attach the DSWE package
library(DSWE)

#set appropriate path for loading the data
path_data = NULL
#set appropriate path for storing the results.
path_results = NULL

#Generating results for the fisrt subplot
#read the datasets
data1 = read.csv(paste0(path_data,'Dataset3_1.csv'))
data2 = read.csv(paste0(path_data,'Dataset3_2.csv'))
datalist = list(data2,data1)
wsCol = 2
tempCol = 4
tiCol = 8
yCol = 6

#match the covariates
matchedDatasets1 = CovMatch(datalist,c(wsCol,tempCol,tiCol))

#generate a test set 
testset1 = as.matrix(seq(1.025*matchedDatasets1$MinMaxMatched[1,1],0.975*matchedDatasets1$MinMaxMatched[2,1],length.out=1000))
matchedData1 = matchedDatasets1$matchedData
rm(matchedDatasets1)
gc()
#run the funGP algorithm
funGPoutput1 = funGP(matchedData1,wsCol,yCol,0.95,testset1)
muDiff1 = -funGPoutput1$muDiff
band1 = funGPoutput1$band
shadeMin = min(which(muDiff1-band1>=0.001))
shadeMax = max(which(muDiff1-band1>=0.001))
shadeIdx = c(shadeMin:shadeMax)

##Generating the results for second subplot
#sample two disjoint datasets from dataset2
set.seed(1)
sampleIdx = sample(nrow(data2), replace = F)
idx1 = floor(nrow(data2)/2)
data2_1 = data2[sampleIdx[c(1:idx1)],]
data2_2 = data2[sampleIdx[-c(1:idx1)],]
datalist2 = list(data2_1,data2_2)

#match the covariates
matchedDatasets2 = CovMatch(datalist2,c(wsCol,tempCol,tiCol))
#generate the testset
testset2 = as.matrix(seq(1.025*matchedDatasets2$MinMaxMatched[1,1],0.975*matchedDatasets2$MinMaxMatched[2,1],length.out=1000))
matchedData2 = matchedDatasets2$matchedData
rm(matchedDatasets2)
gc()
#run the funGP algorithm
funGPoutput2 = funGP(matchedData2,wsCol,yCol,0.95,testset2)
muDiff2 = -funGPoutput2$muDiff
band2 = funGPoutput2$band


##Generating plot
pdf(paste0(path_results,'Figure4.pdf'), height = 6, width = 16)
par(mfrow=c(1,2))
par(mai = c(1.0,1.0,0.5,1.0))
matplot(testset1,cbind(band1,-band1),type = 'l', lwd = 3, col = 'red', lty = 2, ylab = 'Difference of normalized power',xlab = 'Wind speed (m/s)', cex.lab = 1.5, cex.axis = 1.1, ylim = c(-0.25,0.25), xlim = c(0,20))
points(testset1,muDiff1, type = 'l', lwd = 3, col = 'blue')
polygon(x = c(testset1[shadeIdx],rev(testset1[shadeIdx])), y = c(muDiff1[shadeIdx],rev(band1[shadeIdx])), col ="skyblue")
arrows(0,0,max(testset1),0, length = 0, lwd = 1, lty = 2)
legend('topleft',legend = c("Difference","95% Confidence band","Statistical Difference"), lty = c(1,2,NA), pch = c(NA,NA,15),lwd = 2, col = c('blue','red','skyblue'), text.col = c('blue','red', 'black'),pt.cex = 2.0, cex =1.33)
par(mai = c(1.0,1.5,0.5,0.5))
matplot(testset2,cbind(band2,-band2),type = 'l', lwd = 3, col = 'red', lty = 2, ylab = 'Difference of normalized power', xlab = 'Wind speed (m/s)', cex.lab = 1.5, cex.axis = 1.1, ylim = c(-0.25,0.25),xlim = c(0,20))
points(testset2,muDiff2, type = 'l', lwd = 3, col = 'blue')
arrows(0,0,max(testset2),0, length = 0, lwd = 1, lty = 2)
legend('topleft',legend = c("Difference","95% Confidence band"), lty = c(1,2), lwd = 2, col = c('blue','red'), text.col = c('blue','red'), cex =1.33)
dev.off()




